@@ -1,28 +1,28 @@
-/***************************************************************************
- *   Copyright (C) 2010 Alejandro Fiestas Olivares <alex@eyeos.org>        *
- *   Copyright (C) 2010 Eduardo Robles Elvira <edulix@gmail.com>           *
- *   Copyright (C) 2010 UFO Coders <info@ufocoders.com>                    *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*************************************************************************************
+ *  Copyright (C) 2010-2012 by Alejandro Fiestas Olivares <afiestas@kde.org>         *
+ *  Copyright (C) 2010 Eduardo Robles Elvira <edulix@gmail.com>                      *
+ *  Copyright (C) 2010 UFO Coders <info@ufocoders.com>                               *
+ *                                                                                   *
+ *  This program is free software; you can redistribute it and/or                    *
+ *  modify it under the terms of the GNU General Public License                      *
+ *  as published by the Free Software Foundation; either version 2                   *
+ *  of the License, or (at your option) any later version.                           *
+ *                                                                                   *
+ *  This program is distributed in the hope that it will be useful,                  *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
+ *  GNU General Public License for more details.                                     *
+ *                                                                                   *
+ *  You should have received a copy of the GNU General Public License                *
+ *  along with this program; if not, write to the Free Software                      *
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
+ *************************************************************************************/
 
 #include "BlueDevilDaemon.h"
-#include "agentlistener.h"
+#include "bluezagent.h"
 #include "bluedevil_service_interface.h"
 #include "filereceiversettings.h"
+#include "version.h"
 
 #include <QDBusMetaType>
 
@@ -54,7 +54,7 @@ struct BlueDevilDaemon::Private
         Offline
     } m_status;
 
-    AgentListener                   *m_agentListener;
+    BluezAgent                      *m_bluezAgent;
     KFilePlacesModel                *m_placesModel;
     Adapter                         *m_adapter;
     org::kde::BlueDevil::Service    *m_service;
@@ -69,7 +69,7 @@ BlueDevilDaemon::BlueDevilDaemon(QObject *parent, const QList<QVariant>&)
     qDBusRegisterMetaType <DeviceInfo> ();
     qDBusRegisterMetaType <QMapDeviceInfo> ();
 
-    d->m_agentListener = 0;
+    d->m_bluezAgent = 0;
     d->m_adapter = 0;
     d->m_service = 0;
     d->m_placesModel = 0;
@@ -80,13 +80,13 @@ BlueDevilDaemon::BlueDevilDaemon(QObject *parent, const QList<QVariant>&)
         "bluedevildaemon",
         "bluedevil",
         ki18n("Bluetooth Daemon"),
-        "1.0",
+        bluedevil_version,
         ki18n("Bluetooth Daemon"),
         KAboutData::License_GPL,
         ki18n("(c) 2010, UFO Coders")
     );
 
-    aboutData.addAuthor(ki18n("Alejandro Fiestas Olivares"), ki18n("Maintainer"), "alex@eyeos.org",
+    aboutData.addAuthor(ki18n("Alejandro Fiestas Olivares"), ki18n("Maintainer"), "afiestas@kde.org",
         "http://www.afiestas.org");
 
     aboutData.addAuthor(ki18n("Eduardo Robles Elvira"), ki18n("Maintainer"), "edulix@gmail.com",
@@ -179,9 +179,8 @@ void BlueDevilDaemon::onlineMode()
         return;
     }
 
-    d->m_agentListener = new AgentListener();
-    connect(d->m_agentListener, SIGNAL(agentReleased()), this, SLOT(agentReleased()));
-    d->m_agentListener->start();
+    d->m_bluezAgent = new BluezAgent(new QObject());
+    connect(d->m_bluezAgent, SIGNAL(agentReleased()), this, SLOT(agentReleased()));
 
     d->m_adapter = Manager::self()->defaultAdapter();
 
@@ -224,9 +223,9 @@ void BlueDevilDaemon::offlineMode()
 
     d->m_adapter = 0;
 
-    if (d->m_agentListener) {
-        connect(d->m_agentListener, SIGNAL(finished()), this, SLOT(agentThreadStopped()));
-        d->m_agentListener->quit();
+    if (d->m_bluezAgent) {
+        delete d->m_bluezAgent->parent(); // we meed to delete the parent for not leaking it
+        d->m_bluezAgent = 0;
     }
 
     if (isServiceStarted()) {
@@ -257,16 +256,7 @@ void BlueDevilDaemon::offlineMode()
  */
 void BlueDevilDaemon::agentReleased()
 {
-    connect(d->m_agentListener,SIGNAL(finished()),this,SLOT(agentThreadStopped()));
-    d->m_agentListener->quit();
-}
-
-void BlueDevilDaemon::agentThreadStopped()
-{
-    d->m_agentListener->deleteLater();
-    d->m_agentListener = 0;
-
-    kDebug() << "agent listener deleted";
+    //TODO think what to do
 }
 
 void BlueDevilDaemon::defaultAdapterChanged(Adapter *adapter)
