@@ -20,8 +20,11 @@
 
 #include "bluedeviltransfer.h"
 #include "systemcheck.h"
+#include "columnresizer.h"
 #include "ui_transfer.h"
 #include "filereceiversettings.h"
+#include "bluedevil_service.h"
+#include "sharedfilesdialog/sharedfilesdialog.h"
 
 #include <QtCore/QTimer>
 
@@ -30,6 +33,7 @@
 #include <bluedevil/bluedevil.h>
 
 #include <kaboutdata.h>
+#include <klineedit.h>
 #include <kurlrequester.h>
 #include <kpluginfactory.h>
 #include <kconfigdialogmanager.h>
@@ -42,6 +46,7 @@ K_EXPORT_PLUGIN(BlueDevilFactory("bluedeviltransfer", "bluedevil"))
 KCMBlueDevilTransfer::KCMBlueDevilTransfer(QWidget *parent, const QVariantList&)
     : KCModule(BlueDevilFactory::componentData(), parent)
     , m_systemCheck(new SystemCheck(this))
+    , m_restartNeeded(false)
 {
     KAboutData* ab = new KAboutData(
         "kcmbluedeviltransfer", "bluedevil", ki18n("Bluetooth Transfer"), "1.0",
@@ -53,7 +58,7 @@ KCMBlueDevilTransfer::KCMBlueDevilTransfer(QWidget *parent, const QVariantList&)
 
     connect(m_systemCheck, SIGNAL(updateInformationStateRequest()),
             this, SLOT(updateInformationState()));
-
+    connect(this, SIGNAL(changed(bool)), this, SLOT(changed(bool)));
 
     QVBoxLayout *layout = new QVBoxLayout;
     m_systemCheck->createWarnings(layout);
@@ -64,8 +69,21 @@ KCMBlueDevilTransfer::KCMBlueDevilTransfer(QWidget *parent, const QVariantList&)
     layout->addWidget(transfer);
     setLayout(layout);
 
+    m_uiTransfer->kcfg_saveUrl->lineEdit()->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
+
+    m_uiTransfer->kcfg_autoAccept->addItem(i18nc("'Auto accept' option value", "Never"), QVariant(0));
+    m_uiTransfer->kcfg_autoAccept->addItem(i18nc("'Auto accept' option value", "Trusted devices"), QVariant(1));
+    m_uiTransfer->kcfg_autoAccept->addItem(i18nc("'Auto accept' option value", "All devices"), QVariant(2));
+
+    m_uiTransfer->kcfg_requirePin->addItem(i18nc("'Require PIN' option value", "Never"), QVariant(false));
+    m_uiTransfer->kcfg_requirePin->addItem(i18nc("'Require PIN' option value", "Always"), QVariant(true));
+
+    m_uiTransfer->kcfg_allowWrite->addItem(i18nc("'Permissions' option value", "Read Only"), QVariant(false));
+    m_uiTransfer->kcfg_allowWrite->addItem(i18nc("'Permissions' option value", "Modify and Read"), QVariant(true));
+
     addConfig(FileReceiverSettings::self(), transfer);
 
+    connect(m_uiTransfer->sharedFiles, SIGNAL(clicked(bool)), this, SLOT(showSharedFilesDialog()));
     connect(BlueDevil::Manager::self(), SIGNAL(defaultAdapterChanged(Adapter*)),
             this, SLOT(defaultAdapterChanged(Adapter*)));
 
@@ -75,13 +93,37 @@ KCMBlueDevilTransfer::KCMBlueDevilTransfer(QWidget *parent, const QVariantList&)
                 this, SLOT(adapterDiscoverableChanged()));
     }
 
+
     updateInformationState();
+
+    ColumnResizer *resizer = new ColumnResizer(this);
+    resizer->addWidgetsFromFormLayout(m_uiTransfer->formLayout, QFormLayout::LabelRole);
+    resizer->addWidgetsFromFormLayout(m_uiTransfer->formLayout_2, QFormLayout::LabelRole);
 }
 
 KCMBlueDevilTransfer::~KCMBlueDevilTransfer()
 {
 }
 
+void KCMBlueDevilTransfer::save()
+{
+    if (!m_restartNeeded) {
+        return;
+    }
+
+    KCModule::save();
+
+    org::kde::BlueDevil::Service *service = new org::kde::BlueDevil::Service(
+                                                    "org.kde.BlueDevil.Service",
+                                                    "/Service",
+                                                    QDBusConnection::sessionBus(), this);
+    if (service->isRunning()) {
+        service->stopServer();
+    }
+
+    service->launchServer();
+}
+
 void KCMBlueDevilTransfer::defaultAdapterChanged(Adapter *adapter)
 {
     if (adapter) {
@@ -100,3 +142,14 @@ void KCMBlueDevilTransfer::updateInformationState()
 {
     m_systemCheck->updateInformationState();
 }
+
+void KCMBlueDevilTransfer::showSharedFilesDialog()
+{
+    SharedFilesDialog *d = new SharedFilesDialog();
+    d->exec();
+}
+
+void KCMBlueDevilTransfer::changed(bool changed)
+{
+    m_restartNeeded = changed;
+}
