@@ -359,7 +359,7 @@ void Monolithic::regenerateConnectedDevices()
     if (connectedDevices > 0) {
         setOverlayIconByName("emblem-link");
         setToolTipSubTitle(i18ncp("Number of Bluetooth connected devices", "%1 connected device", "%1 connected devices", int(connectedDevices)));
-    } else {
+    } else if(poweredAdapters()) {
         setOverlayIconByName(QString());
         setToolTipSubTitle("");
     }
@@ -613,13 +613,14 @@ void Monolithic::UUIDsChanged(const QStringList &UUIDs)
 void Monolithic::poweredChanged()
 {
     if (!poweredAdapters()) {
+        setIconByName("preferences-system-bluetooth-inactive");
         setTooltipTitleStatus(false);
         setToolTipSubTitle("");
-        setOverlayIconByName("vcs-removed");
     } else {
+        setIconByName("preferences-system-bluetooth");
         setTooltipTitleStatus(true);
-        setOverlayIconByName(QString());
     }
+    setOverlayIconByName(QString());
     regenerateDeviceEntries();
     regenerateConnectedDevices();
 }
